
# Dundas BI

Dundas BI is a state-of-the-art business intelligence platform for data exploration, visual analytics, and creating & sharing dashboards, reports, scorecards, and more. You can deploy Dundas BI as the central data portal for your organization, or integrate it into an existing website as part of a custom or embedded BI solution.

# TL;DR;

```
helm repo add dundas https://helm-charts.dundas.com/repo/
helm install my-dundasbi dundas/dundasbi --set dundas.bi.appDb.appDbConnString="YourConnectionString"
```

# Introduction

This chart bootstraps a Dundas BI deployment on a Kubernetes cluster using the Helm package manager.

This chart has been tested to work with NGINX Ingress.

# Installing the chart

To install the chart with the release name my-dundasbi:

```
helm install my-dundasbi dundas/dundasbi --set dundas.bi.appDb.appDbConnString="YourConnectionString"
```

This command deploys Dundas BI on the Kubernetes cluster in the default configuration. The Parameters section lists the parameters that can be configured during installation.

> **_Tip:_**  List all releases using `helm list`

# Uninstalling the chart

```
helm delete my-dundasbi
```
The command removes all the Kubernetes components associated with the chart and deletes the release.

# Parameters
The following tables lists the configurable parameters of the Dundas BI chart and their default values.

| Parameters | Description | Default |
| ---------- | ----------- | ------- |
| `version`  | The version of Dundas BI images to pull.    | `8.0.0.1001` |
| `dundas.bi.appDb.appDbConnString`  | The application database connection string.  This is used if `dundas.bi.appDb.useExistingSecretForAppDbConnString` is set to false.   | `placeholder` |
| `dundas.bi.appDb.useExistingSecretForAppDbConnString`  | If `dundas.bi.appDb.useExistingSecretForAppDbConnString` is set to `true` the `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName` and `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey` are used to set the application database connection string.  Otherwise, the `dundas.bi.appDb.appDbConnString` is used.   | `false` |
| `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName`  | The name of the secret that has the Dundas BI application database connection string.   | `placeholder` |
| `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey`  | The key of the secret that has the Dundas BI application database connection string.   | `DBI_CONNECTION_STRING` |
| `dundas.bi.appDb.appStorage`  | The application database type either `SqlServer` or `Postgres`.   | SqlServer |
| `dundas.bi.website.port` | The port in the Dundas BI website will be run on. | `8080` |
| `dundas.bi.website.replicaCount` | The number of Dundas BI website replicas.  This is only used if dundas.bi.website.autoscaling.enabled is `false`. | `1` |
| `dundas.bi.website.autoscaling` | This parameters for auto scaling the Dundas BI website.    | `{ enabled: false, minReplicas: 1, maxReplicas: 100, targetCPUUtilizationPercentage: 80 }` |
| `dundas.bi.website.image.override.enabled` | Enables overriding the Dundas BI website image.    | `false` |
| `dundas.bi.website.image.override.name` | The name of the Dundas BI website image to override.    | `` |
| `dundas.bi.website.includeSchedulerInWebsiteContainer` | When `true` this will deploy the scheduler inside the Dundas BI website container.  If this is done you would not need a separate scheduler deployment and you would set `dundas.bi.scheduler.enabled` to `false`.   | `false` |
| `dundas.bi.scheduler.enabled` | This will create the scheduler deployment.  | `true` |
| `dundas.bi.scheduler.replicaCount` | The number of Dundas BI scheduler replicas. | `1` |
| `dundas.bi.scheduler.sleepInSecondsOnStart` | Delay after the website has started to start the scheduler.    | `120` |
| `dundas.bi.scheduler.image.override.enabled` | Enables overriding the Dundas BI scheduler image.    | `false` |
| `dundas.bi.scheduler.image.override.name` | The name of the Dundas BI scheduler image to override.    | `` |
| `image.pullPolicy` | container image pull policy | `IfNotPresent` |
| `image.PullSecrets` | | `[]`
| `service.enabled` | Enable the service.   | `true` |
| `service.type` | The type of service.    | `ClusterIP` |
| `service.sessionAffinity` | The sessionAffinity for the service.    | `ClientIP` |
| `ingress.enabled` | Set to true to enable the ingress.    | `false` |
| `ingress.annotations` | 	Ingress load balancer annotations    | `{}` |
| `ingress.hosts` | Proxied hosts.    | `[]` |
| `ingress.tls` | This maximum number of Dundas BI websites when autoscaling.    | `[]` |

# Defining the Dundas BI connection

There are two ways to define the Dundas BI connection string:

- Define the `dundas.bi.appDb.appDbConnString parameter`, and define the `dundas.bi.appDb.appStorage`.
- Create a secret and set `dundas.bi.appDb.useExistingSecretForAppDbConnString` to `true`.  Next pass the name of the secret with `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretName`, and the key with `dundas.bi.appDb.secretKeyRef.appDbConnStringSecretKey`.  Finally, define the `dundas.bi.appDb.appStorage`. 

# Defining the Dundas BI website

The Dundas BI website parameters are defined as parameters that start with `dundas.bi.website`.  The `dundas.bi.website.port` is the `port` defined in the service.   To scale the Dundas BI website you can either set the `dundas.bi.website.replicaCount` to the number of Dundas BI websites you would like across the cluster, or set the `dundas.bi.website.autoscaling` properties which will take precedence over the `dundas.bi.website.replicaCount` property.  When the `dundas.bi.website.autoscaling.enabled` paramter is `true` a HorizontalPodAutoscaler will be created in Kubernetes with the details.

# Defining the Dundas BI scheduler

The Dundas BI scheduler parameters are defined as parameters that start with `dundas.bi.scheduler`.  Dundas BI requires one scheduler service.  If multiple scheduler services are running only one will do the work at a time, and the other will act as a backup if the other goes down.  The Dundas BI Helm chart allows for multiple ways to set up the scheduler service.  It can be added to every website deployment by setting the `dundas.bi.website.includeSchedulerInWebsiteContainer` to true.  This will add the scheduler to the website deployment container(s).  Alternatively, you can run the scheduler as a separate deployment by setting the `dundas.bi.scheduler.enabled` to `true`.


# Defining the Service

To enable a service to be created with your Dundas BI helm deployment set the `service.enabled` to `true`.  Otherwise it will be expected that after deploying you would set this up manually in Kubernetes.  If you plan on using an ingress the service type is set to the default which is `ClusterIP`.  If want to expose the Dundas BI website but don't plan on using an ingress you would use `ClusterIP` and use a kubectl port forward command, or you can expose it by setting the `service.type` to `LoadBalancer`.

# Load Balancing

It is important to enable sticky sessions for any load balanced implementation of Dundas BI.  The following is an example of the annotations to add to enable sticky sessions with a NGINX ingress controller.

```
ingress:
  enabled: true
  annotations: 
    kubernetes.io/ingress.class: nginx
    kubernetes.io/tls-acme: "true"
    nginx.ingress.kubernetes.io/ssl-redirect: "false"
    nginx.ingress.kubernetes.io/affinity: "cookie"
    nginx.ingress.kubernetes.io/session-cookie-name: "dbiroute"
    nginx.ingress.kubernetes.io/session-cookie-expires: "172800"
    nginx.ingress.kubernetes.io/session-cookie-max-age: "172800"
    nginx.ingress.kubernetes.io/session-cookie-path: /

```

# SSL

It is expected to use an ingress to enable SSL with the Dundas BI Helm chart.  You would first create a secret with your certificate information by calling kubectl:

```
kubectl create secret tls exampledomain --key C:\temp\exampledomain.keyfile --cert C:\temp\exampledomain.certfile
```

Then you would apply that secret to the ingress inside the tls:


```
ingress:
  ...
  hosts:
    - host: exampledomain.com
      paths: 
        - /
  tls: [ { hosts: [ exampledomain.com ], secretName: exampledomain } ]
```

# Image Overriding

In order for certain drivers to work it may be necessary to override the Dundas BI docker images.  In this case you would set `dundas.bi.website.image.override.enabled` to `true` and then defining the new image name `dundas.bi.website.image.override.name`.  Both the Dundas BI website and scheduler contain these properties and can be overridden.

# Upgrading

An upgrade can be accomplished by setting the `version` parameter to a new version.  Upgrading a major version will require a database upgrade and this should be done prior to setting the new `version`.  There are a few ways in which a database upgrade can take place.

* If the database server is on a Kubernetes cluster use `kubectl` to call the setup image of the same version.  The following is the example of this:

```
kubectl run -it mydundassetup --image dundas/dundas-bi-setup:{versionyouwishtodatabaseupgradeto}
```

* Alternatively, you can call a docker command to run the database upgrade:

```
docker run -it dundas/dundas-bi-setup:{versionyouwishtodatabaseupgradeto}
```  
  
Revision upgrades will not require database upgrades and can be done by setting the `version` parameter.  Alternatively, upgrades can be accomplished by overriding the images with new upgraded images.  





